pub struct CKBAppConfig {Show 19 fields
pub bin_name: String,
pub root_dir: PathBuf,
pub data_dir: PathBuf,
pub ancient: PathBuf,
pub tmp_dir: Option<PathBuf>,
pub logger: LogConfig,
pub metrics: MetricsConfig,
pub memory_tracker: MemoryTrackerConfig,
pub chain: ChainConfig,
pub block_assembler: Option<BlockAssemblerConfig>,
pub db: DBConfig,
pub network: NetworkConfig,
pub rpc: RpcConfig,
pub tx_pool: TxPoolConfig,
pub store: StoreConfig,
pub alert_signature: Option<NetworkAlertConfig>,
pub notify: NotifyConfig,
pub indexer: IndexerConfig,
pub fee_estimator: FeeEstimatorConfig,
}Expand description
The main config file for the most subcommands. Usually it is the ckb.toml in the CKB root
directory.
Attention: Changing the order of fields will break integration test, see module doc.
Fields
bin_name: StringThe binary name.
root_dir: PathBufThe root directory.
data_dir: PathBufThe data directory.
ancient: PathBuffreezer files path
tmp_dir: Option<PathBuf>The directory to store temporary files.
logger: LogConfigLogger config options.
metrics: MetricsConfigMetrics options.
Developers can collect metrics for performance tuning and troubleshooting.
memory_tracker: MemoryTrackerConfigMemory tracker options.
Developers can enable memory tracker to analyze the process memory usage.
chain: ChainConfigChain config options.
block_assembler: Option<BlockAssemblerConfig>Block assembler options.
db: DBConfigDatabase config options.
network: NetworkConfigNetwork config options.
rpc: RpcConfigRPC config options.
tx_pool: TxPoolConfigTx pool config options.
store: StoreConfigStore config options.
alert_signature: Option<NetworkAlertConfig>P2P alert config options.
notify: NotifyConfigNotify config options.
indexer: IndexerConfigIndexer config options.
fee_estimator: FeeEstimatorConfigFee estimator config options.
Implementations
Sourceimpl CKBAppConfig
impl CKBAppConfig
Sourcepub fn load_from_slice(slice: &[u8]) -> Result<Self, ExitCode>
pub fn load_from_slice(slice: &[u8]) -> Result<Self, ExitCode>
Load a new instance from a file