pub struct MinerClientConfig {
pub rpc_url: String,
pub poll_interval: u64,
pub block_on_submit: bool,
pub listen: Option<SocketAddr>,
pub auth_token: Option<String>,
}Expand description
RPC client config options.
Fields
rpc_url: StringCKB node RPC endpoint.
poll_interval: u64The poll interval in seconds to get work from the CKB node.
block_on_submit: boolBy default, miner submits a block and continues to get the next work.
When this is enabled, miner will block until the submission RPC returns.
listen: Option<SocketAddr>listen block_template notify instead of loop poll
auth_token: Option<String>Optional bearer token to authenticate block-template notifications.
When listen is set and this token is configured, incoming notify
requests must include the header Authorization: Bearer <token>.
If listen is set but this token is not configured, ckb-miner will
accept any request that deserializes as a BlockTemplate, which can be
abused if the notify endpoint is reachable by untrusted parties.
Must be non-empty and free of leading/trailing whitespace; ckb-miner refuses to start otherwise.